==> haskell-wai-middleware-static-0.8.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.2
id: wai-middleware-static-0.8.2-6NKq7K8RjrT5hFMNI3INCI
key: wai-middleware-static-0.8.2-6NKq7K8RjrT5hFMNI3INCI
license: BSD-3-Clause
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
author: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
abi: a7c16efac41f2292eb416bd09ee447b5
exposed: True
exposed-modules:
    Network.Wai.Middleware.Static
import-dirs: /usr/lib/ghc-8.4.2/site-local/wai-middleware-static-0.8.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/wai-middleware-static-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/wai-middleware-static-0.8.2
hs-libraries: HSwai-middleware-static-0.8.2-6NKq7K8RjrT5hFMNI3INCI
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi directory-1.3.1.5
    expiring-cache-map-0.0.6.1-2HTzQkS2MKXHTicXo4fu86 filepath-1.4.2
    http-types-0.12.1-9G9IqNV3a1x8yQKrYijGm4
    mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4 mtl-2.2.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh text-1.2.3.0 time-1.8.0.2
    wai-3.2.1.2-Jkqr5D5Ikr6AZy2opdSgyr
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=fe88b1a2ffec9ea7c1970408b9b1825d
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=ed2d5adcedeb6833cc2a392fb853e830
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             expiring-cache-map-0.0.6.1-2HTzQkS2MKXHTicXo4fu86=7114639f38bee20755b7324fd48ee7d4
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             http-types-0.12.1-9G9IqNV3a1x8yQKrYijGm4=2c2dad893bbea8aafb573db454497a33
             mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4=e67c2acc5ecf4421eadbd12de2e86a0b
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=2dfd38519bdeae449859dd6952bd60c2
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             time-1.8.0.2=f5b6d28c2b89a17d60f5dfeda767abd0
             wai-3.2.1.2-Jkqr5D5Ikr6AZy2opdSgyr=eef9b0310d2b990a855396aa8478245e
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.8.2-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.2
id: wai-middleware-static-0.8.2-45ES22mGFz9lPamjvSXtn
key: wai-middleware-static-0.8.2-45ES22mGFz9lPamjvSXtn
license: BSD-3-Clause
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
author: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
abi: c89cb2d4322bbb7ae1b1442e210cd7ab
exposed: True
exposed-modules:
    Network.Wai.Middleware.Static
import-dirs: /usr/lib/ghc-8.4.2/site-local/wai-middleware-static-0.8.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/wai-middleware-static-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/wai-middleware-static-0.8.2
hs-libraries: HSwai-middleware-static-0.8.2-45ES22mGFz9lPamjvSXtn
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi directory-1.3.1.5
    expiring-cache-map-0.0.6.1-2HTzQkS2MKXHTicXo4fu86 filepath-1.4.2
    http-types-0.12.1-KnBXWodAiMB133wyXZGxL
    mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4 mtl-2.2.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh text-1.2.3.0 time-1.8.0.2
    wai-3.2.1.2-420X8YkwoJz2aOuzoLWJLG
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=fe88b1a2ffec9ea7c1970408b9b1825d
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=ed2d5adcedeb6833cc2a392fb853e830
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             expiring-cache-map-0.0.6.1-2HTzQkS2MKXHTicXo4fu86=7114639f38bee20755b7324fd48ee7d4
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             http-types-0.12.1-KnBXWodAiMB133wyXZGxL=04753b38c49e8e043065bb4b950c4c35
             mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4=e67c2acc5ecf4421eadbd12de2e86a0b
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=2dfd38519bdeae449859dd6952bd60c2
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             time-1.8.0.2=f5b6d28c2b89a17d60f5dfeda767abd0
             wai-3.2.1.2-420X8YkwoJz2aOuzoLWJLG=119e6da9a61e4f39cb1cae65a84c6fd0
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
